@@ -1,8 +1,7 @@
 # -*-Perl-*-
-# $Id: CTlib.pm,v 1.28 1999/04/16 16:54:01 mpeppler Exp $
-# @(#)CTlib.pm	1.27	03/26/99
+# @(#)CTlib.pm	1.13	1/5/96
 
-# Copyright (c) 1995-1997
+# Copyright (c) 1995
 #   Michael Peppler
 #
 #   Parts of this file are
@@ -13,72 +12,6 @@
 #   or the Artistic License, copies of which should have accompanied
 #   your Perl kit.
 
-require 5.002;
-
-use strict;
-
-package Sybase::CTlib::_attribs;
-
-use Carp;
-
- 
-sub FIRSTKEY {
-    each %{$_[0]};
-}
-
-sub NEXTKEY {
-    each %{$_[0]};
-}
-
-sub EXISTS{ 
-     exists($_[0]->{$_[1]});
-}
-
-
-sub readonly {
-    carp "Can't delete or clear attributes from a Sybase::CTlib handle.\n";
-}
-
-sub DELETE{ &readonly }
-sub CLEAR { &readonly }
-
-package Sybase::CTlib::Att;
-
-use Carp;
-
-sub TIEHASH {
-    bless {UseDateTime => 0,
-	   UseMoney => 0,
-	   UseNumeric => 0,
-	   MaxRows => 0}
-}
-sub FETCH { 
-    return $_[0]->{$_[1]} if (exists $_[0]->{$_[1]});
-    return undef;
-}
- 
-sub FIRSTKEY {
-    each %{$_[0]};
-}
-
-sub NEXTKEY {
-    each %{$_[0]};
-}
-
-sub EXISTS{ 
-     exists($_[0]->{$_[1]});
-}
-
-sub STORE {
-    croak("'$_[1]' is not a valid Sybase::CTlib attribute") if(!exists($_[0]->{$_[1]}));
-    $_[0]->{$_[1]} = $_[2];
-}
-
-sub readonly { croak "\%Sybase::CTlib::Att is read-only\n" }
-
-sub DELETE{ &readonly }
-sub CLEAR { &readonly }
-
 package Sybase::CTlib::DateTime;
 
 # Sybase DATETIME handling.
@@ -87,11 +20,12 @@ package Sybase::CTlib::DateTime;
 
 require Time::Local;
 
+require POSIX;
 
 # Here we set up overloading operators
 # for certain operations.
 
-use overload ("\"\"" => \&d_str,		# convert to string
+%OVERLOAD = ("\"\"" => \&d_str,		# convert to string
 	     "cmp" => \&d_cmp,		# compare two dates
 	     "<=>" => \&d_cmp);		# same thing
 
@@ -111,19 +45,10 @@ sub mktime {
     my $self = shift;
     my (@data, $ret);
 
-    # Wrapped in an eval() in case POSIX is not compiled in this
-    # copy of Perl.
-    eval {
-    require POSIX;		# This isn't very clean, but it speeds
-				# up loading for something that is rarely
-				# used...
-    
     @data = $self->crack;
 
     $ret = POSIX::mktime($data[7], $data[6], $data[5], $data[2],
-			 $data[1], $data[0]-1900);
-    };
-    $ret;
+				  $data[1], $data[0]-1900);
 }
 
 sub timelocal {
@@ -152,7 +77,7 @@ package Sybase::CTlib::Money;
 # Sybase MONEY handling. Again, we set up overloading for
 # certain operators (in particular the arithmetic ops.)
 
-use overload ("\"\"" => \&m_str,		# Convert to string
+%OVERLOAD = ("\"\"" => \&m_str,		# Convert to string
 	     "0+" => \&m_num,		# Convert to floating point
 	     "<=>" => \&m_cmp,		# Compare two money items
 	     "+" => \&m_add,		# These you can guess...
@@ -206,7 +131,7 @@ package Sybase::CTlib::Numeric;
 # Sybase Numeric/Decimal handling. Again, we set up overloading for
 # certain operators (in particular the arithmetic ops.)
 
-use overload ("\"\"" => \&n_str,		# Convert to string
+%OVERLOAD = ("\"\"" => \&n_str,		# Convert to string
 	     "0+" => \&n_num,		# Convert to floating point
 	     "<=>" => \&n_cmp,		# Compare
 	     "+" => \&n_add,		# These you can guess...
@@ -255,28 +180,64 @@ sub n_div {
     $left->calc($right, '/', $order);
 }
 
+package Sybase::CTlib::Att;
+
+use Carp;
+
+sub TIEHASH { bless {UseDateTime => 0,
+		 UseMoney => 0,
+		 UseNumeric => 0,
+		 MaxRows => 0}
+	  }
+sub FETCH { 
+    return $_[0]->{$_[1]} if (exists $_[0]->{$_[1]});
+    return undef;
+}
+ 
+sub FIRSTKEY {
+    each %{$_[0]};
+}
+
+sub NEXTKEY {
+    each %{$_[0]};
+}
+
+sub EXISTS{ 
+     exists($_[0]->{$_[1]});
+}
+
+sub STORE {
+    croak("'$_[1]' is not a valid Sybase::CTlib attribute") if(!defined($_[0]->{$_[1]}));
+    $_[0]->{$_[1]} = $_[2];
+}
+
+sub readonly { croak "\%Sybase::CTlib::Att is read-only\n" }
+
+sub DELETE{ &readonly }
+sub CLEAR { &readonly }
+
+
 
 package Sybase::CTlib;
 
 require Exporter;
-use AutoLoader;
+require AutoLoader;
 require DynaLoader;
 
-use Carp;
+# This does not work with 5.001 (produces a lot of 'subroutine redefined'
+# warnings...
+if($] >= 5.002) {
+eval '
+use subs qw(CS_SUCCEED CS_ROW_RESULT CS_PARAM_RESULT CS_STATUS_RESULT
+	    CS_CURSOR_RESULT CS_COMPUTE_RESULT CS_CANCEL_CURRENT);
+'
+}
 
-use subs qw(CS_SUCCEED CS_FAIL CS_CMD_DONE CS_ROW_COUNT
-  CS_ROW_RESULT CS_PARAM_RESULT CS_STATUS_RESULT CS_CURSOR_RESULT
-  CS_COMPUTE_RESULT CS_CANCEL_CURRENT);
-
-use vars qw(%Att @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD 
-	    $res_type %fetchable);
-
-%EXPORT_TAGS = (minimal => [qw(CS_SUCCEED CS_FAIL ct_callback CS_CMD_FAIL)]);
-
-@ISA = qw(Exporter DynaLoader);
+@ISA = qw(Exporter AutoLoader DynaLoader);
 # Items to export into callers namespace by default
 # (move infrequently used names to @EXPORT_OK below)
-@EXPORT = qw( ct_callback ct_config cs_dt_info
+@EXPORT = qw(
+	     ct_callback
 	CS_12HOUR
 	CS_ABSOLUTE
 	CS_ACK
@@ -290,7 +251,9 @@ use vars qw(%Att @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD
 	CS_ASYNC_NOTIFS
 	CS_BINARY_TYPE
 	CS_BIT_TYPE
+	CS_BLKDESC
 	CS_BLK_HAS_TEXT
+	CS_BLK_ROW
 	CS_BOUNDARY_TYPE
 	CS_BROWSE_INFO
 	CS_BULK_CONT
@@ -319,6 +282,7 @@ use vars qw(%Att @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD
 	CS_CMD_NUMBER
 	CS_CMD_SUCCEED
 	CS_COLUMN_DATA
+	CS_COMMAND
 	CS_COMMBLOCK
 	CS_COMPARE
 	CS_COMPLETION_CB
@@ -328,9 +292,11 @@ use vars qw(%Att @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD
 	CS_COMP_COLID
 	CS_COMP_ID
 	CS_COMP_OP
+	CS_CONNECTION
 	CS_CONNECTNAME
 	CS_CONSTAT_CONNECTED
 	CS_CONSTAT_DEAD
+	CS_CONTEXT
 	CS_CONTINUE
 	CS_CONV_ERR
 	CS_CON_INBAND
@@ -556,7 +522,9 @@ use vars qw(%Att @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD
 	CS_LC_MONETARY
 	CS_LC_NUMERIC
 	CS_LC_TIME
+	CS_LOCALE
 	CS_LOC_PROP
+	CS_LOGINFO
 	CS_LOGIN_STATUS
 	CS_LOGIN_TIMEOUT
 	CS_LONGBINARY_TYPE
@@ -810,37 +778,81 @@ use vars qw(%Att @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD
 	CS_VER_STRING
 	CS_WILDCARD
 	CS_ZERO
+	CT_BIND
+	CT_BR_COLUMN
+	CT_BR_TABLE
+	CT_CALLBACK
+	CT_CANCEL
+	CT_CAPABILITY
+	CT_CLOSE
+	CT_CMD_ALLOC
+	CT_CMD_DROP
+	CT_CMD_PROPS
+	CT_COMMAND
+	CT_COMPUTE_INFO
+	CT_CONFIG
+	CT_CONNECT
+	CT_CON_ALLOC
+	CT_CON_DROP
+	CT_CON_PROPS
+	CT_CON_XFER
+	CT_CURSOR
+	CT_DATA_INFO
+	CT_DEBUG
+	CT_DESCRIBE
+	CT_DIAG
+	CT_DYNAMIC
+	CT_DYNDESC
+	CT_EXIT
+	CT_FETCH
+	CT_GETFORMAT
+	CT_GETLOGINFO
+	CT_GET_DATA
+	CT_INIT
+	CT_KEYDATA
+	CT_LABELS
+	CT_NOTIFICATION
+	CT_OPTIONS
+	CT_PARAM
+	CT_POLL
+	CT_RECVPASSTHRU
+	CT_REMOTE_PWD
+	CT_RESULTS
+	CT_RES_INFO
+	CT_SEND
+	CT_SENDPASSTHRU
+	CT_SEND_DATA
+	CT_SETLOGINFO
+	CT_USER_FUNC
+	CT_WAKEUP
+	SQLCA_TYPE
+	SQLCODE_TYPE
+	SQLSTATE_TYPE
 );
 # Other items we are prepared to export if requested
-@EXPORT_OK = qw(TRACE_NONE TRACE_ALL TRACE_CREATE TRACE_DESTROY TRACE_SQL
-    TRACE_RESULTS TRACE_FETCH TRACE_CURSOR TRACE_PARAMS	TRACE_OVERLOAD
-    SQLCA_TYPE SQLCODE_TYPE SQLSTATE_TYPE
-    CT_BIND CT_BR_COLUMN CT_BR_TABLE CT_CALLBACK CT_CANCEL CT_CAPABILITY
-    CT_CLOSE CT_CMD_ALLOC CT_CMD_DROP CT_CMD_PROPS CT_COMMAND CT_COMPUTE_INFO
-    CT_CONFIG CT_CONNECT CT_CON_ALLOC CT_CON_DROP CT_CON_PROPS CT_CON_XFER
-    CT_CURSOR CT_DATA_INFO CT_DEBUG CT_DESCRIBE CT_DIAG CT_DYNAMIC
-    CT_DYNDESC CT_EXIT CT_FETCH CT_GETFORMAT CT_GETLOGINFO CT_GET_DATA
-    CT_INIT CT_KEYDATA CT_LABELS CT_NOTIFICATION CT_OPTIONS CT_PARAM
-    CT_POLL CT_RECVPASSTHRU CT_REMOTE_PWD CT_RESULTS CT_RES_INFO CT_SEND
-    CT_SENDPASSTHRU CT_SEND_DATA CT_SETLOGINFO CT_USER_FUNC CT_WAKEUP
+@EXPORT_OK = qw(
 );
 
+#%Att = (UseDateTime => 0,
+#	UseMoney => 0,
+#	UseNumeric => 0,
+#	MaxRows => 0);
 
-tie %Att, 'Sybase::CTlib::Att';
+tie %Att, Sybase::CTlib::Att;
 
 sub AUTOLOAD {
-    my $constname;
+    local($constname);
     ($constname = $AUTOLOAD) =~ s/.*:://;
-    
-    # The second argument to constant() is never used...
-    my $val = constant($constname, 0);
+    $val = constant($constname, @_ ? $_[0] : 0);
     if ($! != 0) {
 	if ($! =~ /Invalid/) {
 	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
 	    goto &AutoLoader::AUTOLOAD;
 	}
 	else {
-	    croak "Your vendor has not defined Sybase::CTlib macro $constname";
+	    ($pack,$file,$line) = caller;
+	    die "Your vendor has not defined Sybase::CTlib macro $constname, used at $file line $line ($pack).
+";
 	}
     }
     eval "sub $AUTOLOAD { $val }";
@@ -856,69 +868,44 @@ bootstrap Sybase::CTlib;
 
 *new = \&ct_connect;
 
-# Use a hash table for fast lookups:
-
-@fetchable{
-  &CS_ROW_RESULT,
-  &CS_PARAM_RESULT,
-  &CS_STATUS_RESULT,
-  &CS_CURSOR_RESULT,
-  &CS_COMPUTE_RESULT} = (1) x 5;
-
-sub ct_fetchable
-{
-    $fetchable{$_[1]};
-}
-
-
 
+1;
+__END__
 
 
 sub ct_sql
 {
-    my($db, $cmd, $sub, $flag) = @_;
-    my(@res, $data, $rc);
-    local($res_type);  # it's local so that it can be examined by &$sub
-    my $fail = 0;
+    my($db, $cmd, $sub) = @_;
+    my(@res, @data, $res_type, $rc);
+    my($count, $max);
 
-    if($db->{'MaxRows'}) {
-	$db->ct_options(&CS_SET, &CS_OPT_ROWCOUNT, $db->{MaxRows},
-			&CS_INT_TYPE);
-    }
-    ($db->ct_execute($cmd) == &CS_SUCCEED) || return undef;
+    ($db->ct_execute($cmd) == CS_SUCCEED) || return undef;
 
-    $res_type = 0;		# avoid 'unitialized variable' warnings...
-    $flag = 0 unless $flag;
+    $max = $db->{'MaxRows'};
 
+    while(($rc = $db->ct_results($res_type)) == CS_SUCCEED) {
+	next if($db->ct_fetchable($res_type) == 0);
 
-    while(($rc = $db->ct_results($res_type)) == &CS_SUCCEED) {
-        $db->{'ROW_COUNT'} = $db->ct_res_info(&CS_ROW_COUNT)
-            if $res_type == &CS_CMD_DONE;
-	$fail = 1 if ($res_type == &CS_CMD_FAIL);
-	next unless $fetchable{$res_type};
-
-        while ($data = $db->ct_fetch($flag, 1)) {
+        while (@data = $db->ct_fetch) {
             if (defined $sub) {
-		if($flag) {
-		    &$sub(%$data);
-		} else {
-		    &$sub(@$data);
-		}
+                &$sub(@data);
             } else {
-		if($flag) {
-		    push(@res, {%$data});
-		} else {
-		    push(@res, [@$data]);
-		}
+		last if($max && ++$count > $max);
+                push(@res, [@data]);
             }
         }
+	$db->ct_cancel(CS_CANCEL_CURRENT) if($max && $count > $max);
     }
-    if($db->{'MaxRows'}) {
-	$db->ct_options(&CS_SET, &CS_OPT_ROWCOUNT, 0, &CS_INT_TYPE);
-    }
-    $db->{RC} = $fail ? CS_FAIL : $rc;
     wantarray ? @res : \@res;  # return the result array
 }
 
-1;
-__END__
+sub ct_fetchable
+{
+    my($db, $restype) = @_;
+    
+   ($restype == CS_ROW_RESULT ||
+    $restype == CS_PARAM_RESULT ||
+    $restype == CS_STATUS_RESULT ||
+    $restype == CS_CURSOR_RESULT ||
+    $restype == CS_COMPUTE_RESULT);
+}
