@@ -1,8 +1,5 @@
 # -*-Perl-*-
-# $Id: Sybperl.pm,v 1.28 1999/05/14 18:10:09 mpeppler Exp $
-#
-# From
-# 	@(#)Sybperl.pm	1.27	03/26/98
+# @(#)Sybperl.pm	1.21	12/22/95
 #
 # Copyright (c) 1994-1995
 #   Michael Peppler
@@ -11,39 +8,6 @@
 #   or the Artistic License, copies of which should have accompanied
 #   your Perl kit.
 
-package Sybase::Sybperl;
-
-=head1 NAME
-
-Sybase::Sybperl - sybperl 1.0xx emulation module
-
-=head1 SYNOPSYS
-
-    require 'sybperl.pl';
-
-    $dbproc = dblogin($user, $pwd, $server);
-    dbcmd($dbproc, "select * from sysusers");
-    dbsqlexec($dbproc);
-    dbresults($dbproc);
-    while(@data = dbnextrow($dbproc)) {
-        print "@data\n";
-    }
-
-=head1 DESCRIPTION
-
-The Sybase::Sybperl module is provided to ease porting old perl4/sybperl 1.x
-programs to perl5. It is not recommended that this module be used for
-any new project. See L<Sybase::DBlib> or L<Sybase::CTlib> for alternatives.
-
-The old sybperl 1.0xx manpage is in the pod/sybperl-1.0xx.man in the
-sybperl source distribution.
-
-=head1 AUTHOR
-
-Michael Peppler F<E<lt>mpeppler@peppler.orgE<gt>>.
-
-=cut
-
 package Sybase::Sybperl::Attribs;
 
 sub TIESCALAR {
@@ -75,10 +39,10 @@ package Sybase::Sybperl;
 
 use Carp;
 require Exporter;
-use AutoLoader 'AUTOLOAD';
+require AutoLoader;
 use Sybase::DBlib;
 
-@ISA = qw(Exporter);
+@ISA = qw(Exporter AutoLoader);
 
 $SUCCEED = Sybase::DBlib::SUCCEED;
 $FAIL = Sybase::DBlib::FAIL;
@@ -102,7 +66,7 @@ tie $dbBin0x, Sybase::Sybperl::Attribs, 'dbBin0x', 0;
 @EXPORT = qw(dblogin dbcmd dbsqlexec dbresults dbnextrow dbstrcpy
 	     dbuse dbopen dbclose
 	     $SUCCEED $FAIL $NO_MORE_RESULTS $NO_MORE_ROWS
-	     $MORE_ROWS $REG_ROW $DBTRUE $DBFALSE $DB_IN $DB_OUT
+	     $MORE_ROWS $REG_ROW $DBTRUE $DBFALSE
 	     $dbNullIsUndef $dbKeepNumeric $dbBin0x
 	     bcp_init bcp_meminit bcp_sendrow bcp_batch bcp_done
 	     bcp_control bcp_columns bcp_colfmt bcp_collen bcp_exec
@@ -127,8 +91,7 @@ tie $dbBin0x, Sybase::Sybperl::Attribs, 'dbBin0x', 0;
 	     dbmnymul dbmnyminus dbmnydivide dbmnyadd dbmny4zero
 	     dbmny4cmp dbmny4sub dbmny4mul dbmny4minus dbmny4divide
 	     dbmny4add sql
-	     dbrpcinit dbrpcparam dbrpcsend
-	     dbwritetext dbreadtext dbmoretext dbpreptext);
+	     dbrpcinit dbrpcparam dbrpcsend);
 
 
 # Internal routine to check that a parameter passed as $dbproc to one
@@ -185,12 +148,8 @@ sub dbclose
     croak "&dbclose() must be called with an argument!\n"
 	if(!defined($dbproc) || !&isadb($dbproc));
 
-    if($default_db == $dbproc) {
-	undef($default_db);
-    }
-
     delete($DBprocs{$dbproc});
-    $dbproc->force_dbclose;
+    $dbproc->dbclose;
     undef($dbproc);
 }
 
@@ -256,20 +215,6 @@ sub dbsqlexec
     $ret;
 }
 
-sub dbsqlok
-{
-    my($dbproc) = @_;
-    my($ret);
-
-    if(!defined($dbproc) || !$dbproc || !&isadb($dbproc))
-    {
-	croak("It doesn't make sense to call dbsqlok with an undefined \$dbproc") if(!defined($default_db));
-	$dbproc = $default_db;
-    }
-    $ret = $dbproc->dbsqlok;
-    $ret;
-}
-
 sub dbresults
 {
     my($dbproc) = @_;
@@ -299,7 +244,7 @@ sub dbnextrow
     
     @row = $dbproc->dbnextrow(@params);
     
-    $main::ComputeId = $dbproc->{'ComputeID'};
+    $main::ComputeID = $dbproc->{'ComputeID'};
     $main::DBstatus = $dbproc->{'DBstatus'};
 
     @row;
@@ -380,28 +325,6 @@ sub dbfreebuf
     $dbproc->dbfreebuf;
 }
 
-sub dbsetopt
-{
-    my($dbproc, @param) = @_;
-
-    $dbproc->dbsetopt(@param);
-}
-
-sub dbclropt
-{
-    my($dbproc, @param) = @_;
-
-    $dbproc->dbclropt(@param);
-}
-
-sub dbisopt
-{
-    my($dbproc, @param) = @_;
-
-    $dbproc->dbisopt(@param);
-}
-
-
 sub DBCURCMD
 {
     my($dbproc) = @_;
@@ -1164,115 +1087,4 @@ sub dbrpcinit
     $dbproc->dbrpcinit(@param);
 }
 
-sub dbreginit
-{
-    my(@param) = @_;
-    my($dbproc);
-
-    if(@param == 2)
-    {
-	$dbproc = shift(@param);
-    }
-    else
-    {
-	$dbproc = $default_db;
-    }
-
-    $dbproc->dbreginit(@param);
-}
-
-sub dbreglist
-{
-    my(@param) = @_;
-    my($dbproc);
-
-    if(@param == 1)
-    {
-	$dbproc = shift(@param);
-    }
-    else
-    {
-	$dbproc = $default_db;
-    }
-
-    $dbproc->dbreglist(@param);
-}
-
-sub dbregparam
-{
-    my(@param) = @_;
-    my($dbproc);
-
-    if(@param == 5)
-    {
-	$dbproc = shift(@param);
-    }
-    else
-    {
-	$dbproc = $default_db;
-    }
-
-    $dbproc->dbregparam(@param);
-}
-
-sub dbregexec
-{
-    my(@param) = @_;
-    my($dbproc);
-
-    if(@param == 2)
-    {
-	$dbproc = shift(@param);
-    }
-    else
-    {
-	$dbproc = $default_db;
-    }
-
-    $dbproc->dbregexec(@param);
-}
-
-sub dbwritetext
-{
-    my(@params) = @_;
-    my($dbproc);
-
-    $dbproc = shift(@params);
-
-    $dbproc->dbwritetext(@params);
-}
-
-sub dbreadtext
-{
-    my(@params) = @_;
-    my($dbproc);
-
-    $dbproc = shift(@params);
-
-    $dbproc->dbwritetext(@params);
-}
-
-sub dbmoretext
-{
-    my(@params) = @_;
-    my($dbproc);
-
-    $dbproc = shift(@params);
-
-    $dbproc->dbmoretext(@params);
-}
-
-sub dbpreptext
-{
-    my(@params) = @_;
-    my($dbproc);
-
-    $dbproc = shift(@params);
-
-    $dbproc->dbpreptext(@params);
-}
-
-
 1;
-
-
